- [Dearborn’s Finest Fantasy Football League Constitution](#dearborns-finest-fantasy-football-league-constitution)
  - [1. League Structure](#1-league-structure)
    - [1.1 League Name](#11-league-name)
    - [1.2 League Size](#12-league-size)
    - [1.3 League Hosting Site](#13-league-hosting-site)
    - [1.4 League Dictatorship](#14-league-dictatorship)
  - [2. League Roles](#2-league-roles)
    - [2.1 Commissioner](#21-commissioner)
    - [2.2 Co-Commissioner](#22-co-commissioner)
    - [2.3 Trade Administrator](#23-trade-administrator)
    - [2.4 Associate Trade Administer](#24-associate-trade-administer)
    - [2.5 Communications Administrator](#25-communications-administrator)
    - [2.6 Associate Communications Administrator](#26-associate-communications-administrator)
    - [2.7 Secretary](#27-secretary)
    - [2.8 Treasurer](#28-treasurer)
    - [2.9 Bet Arbiter](#29-bet-arbiter)
    - [2.10 Chief Technical Officer of Feta Research and Development for the Americas and Europe (CTOFRDAE)](#210-chief-technical-officer-of-feta-research-and-development-for-the-americas-and-europe-ctofrdae)
  - [3. Trades](#3-trades)
    - [3.1 Trade Review Process](#31-trade-review-process)
    - [3.2 Commissioner Trade Review Process](#32-commissioner-trade-review-process)
    - [3.3 Trade Deadline](#33-trade-deadline)
    - [3.4 Post Trade Stipulations](#34-post-trade-stipulations)
  - [4. Waivers](#4-waivers)
    - [4.1 FAAB](#41-faab)
    - [4.2 Waiver Priority](#42-waiver-priority)
    - [4.3 Waiver Claims](#43-waiver-claims)
    - [4.4 Post Draft Waiver Wire](#44-post-draft-waiver-wire)
    - [4.5 Waiver Period and Processing](#45-waiver-period-and-processing)
  - [5. Monetary](#5-monetary)
    - [5.1 Fees and Collection](#51-fees-and-collection)
    - [5.2 Distribution](#52-distribution)
  - [6. Schedule](#6-schedule)
    - [6.1 Schedule Planning](#61-schedule-planning)
  - [7. Team Structure](#7-team-structure)
    - [7.1 Team Size](#71-team-size)
    - [7.2 Position Breakdown](#72-position-breakdown)
    - [7.3 Injured Reserve](#73-injured-reserve)
  - [8. Scoring](#8-scoring)
    - [8.1 Fractional Scoring](#81-fractional-scoring)
    - [8.2 Points Per Reception](#82-points-per-reception)
    - [8.3 Quarterbacks (QB)](#83-quarterbacks-qb)
    - [8.4 Running Backs (RB)](#84-running-backs-rb)
    - [8.5 Wide Receivers (WR)](#85-wide-receivers-wr)
    - [8.6 Tight Ends (TE)](#86-tight-ends-te)
    - [8.7 Kickers (K)](#87-kickers-k)
    - [8.8 All Offense](#88-all-offense)
    - [8.9 Defense and Special Teams (DST)](#89-defense-and-special-teams-dst)
  - [9. Penalities](#9-penalities)
    - [9.1 Illegal Lineups](#91-illegal-lineups)
  - [10. Communication](#10-communication)
    - [10.1 League Wide Announcements](#101-league-wide-announcements)
    - [10.2 Signal](#102-signal)
  - [11. Playoffs](#11-playoffs)
    - [11.1 Playoff Qualifying](#111-playoff-qualifying)
    - [11.2 Playoff Seeding](#112-playoff-seeding)
    - [11.3 Playoff Schedule](#113-playoff-schedule)
    - [11.4 Playoff Waivers](#114-playoff-waivers)
    - [11.5 Eliminated teams](#115-eliminated-teams)
  - [12. Awards](#12-awards)
    - [12.1 Trophy](#121-trophy)
    - [12.2 Prize Money](#122-prize-money)
  - [13. Rule Ammendments](#13-rule-ammendments)
    - [2015 Summit Topics](#2015-summit-topics)
    - [2015 Summit Outcomes](#2015-summit-outcomes)
    - [2016 Summit Topics](#2016-summit-topics)
    - [2016 Summit Outcomes](#2016-summit-outcomes)
    - [2017 Summit Topics](#2017-summit-topics)
    - [2017 Summit Outcomes](#2017-summit-outcomes)
    - [2018 Summit Topics](#2018-summit-topics)
    - [2018 Summit Outcomes](#2018-summit-outcomes)
    - [2019 Summit Topics](#2019-summit-topics)
    - [2019 Summit Outcomes](#2019-summit-outcomes)
    - [2020 Summit Topics](#2020-summit-topics)
    - [2020 Summit Outcomes](#2020-summit-outcomes)
    - [2021 Summit Topics](#2021-summit-topics)
    - [2021 Summit Outcomes](#2021-summit-outcomes)

# Dearborn’s Finest Fantasy Football League Constitution  
*A Yearly Tradition: Sixteen Weeks of Relentless Torture-  

## 1. League Structure  
### 1.1 League Name  
- The league name shall be *Dearborn's Finest*.

### 1.2 League Size  
- The league size shall consist of *12- teams.

### 1.3 League Hosting Site  
- The league shall operate on *Yahoo*.

### 1.4 League Dictatorship  
- The league *is- a dictatorship.

## 2. League Roles  
### 2.1 Commissioner  
- Tom Brady

### 2.2 Co-Commissioner  
- Mike Gardner  
- Jason Qarana  

### 2.3 Trade Administrator  
- Mike Gardner

### 2.4 Associate Trade Administer  
- Ziad Shounia

### 2.5 Communications Administrator  
- Ray Brikho

### 2.6 Associate Communications Administrator  
- Tom Brady

### 2.7 Secretary  
- Tom Brady

### 2.8 Treasurer  
- Tom Brady

### 2.9 Bet Arbiter  
- Tom Brady

### 2.10 Chief Technical Officer of Feta Research and Development for the Americas and Europe (CTOFRDAE)  
- Dr. Bashar Alnarraie, Ph.D, MD, B.S.E.E., MBA, PMP

## 3. Trades  
### 3.1 Trade Review Process  
- If both parties agree to trade, it goes to Commissioner approval.
- Trades are reviewed by trade parties and Commissioner.
- The trade is evaluated by the Commissioner based on both current teams’ rosters, Commissioner’s discretion, and the CBS trade value chart.
- The Commissioner can also contact the Trade Administrator (TA) or Associate Trade Administrator (ATA) for an impartial discussion.
- In the event the trade involves the TA, the ATA can be contacted for impartial discussion.
- In the event the trade involves the ATA, the TA can be contacted for impartial discussion.
- Once the trade is deemed fair for both parties involved, the Commissioner will contact both parties for final confirmation.
- The trade will be processed immediately after.

### 3.2 Commissioner Trade Review Process  
- In the event the Commissioner wants to trade with another person, the TA will evaluate the trade using the same procedure.
- In the event the Commissioner wants to trade with the TA, the ATA will evaluate the trade using the same procedure.

### 3.3 Trade Deadline  
- The last week for trading will be the week of Thanksgiving.

### 3.4 Post Trade Stipulations  
- After the trade has been processed, it will be announced in the league chat.
- After the trade has been processed, the players who are traded for must remain on the manager’s rosters until the following Tuesday morning at the minimum.
- If this stipulation is not followed, a penalty will be enforced as outlined in the penalty section.

## 4. Waivers  
### 4.1 FAAB  
- FAAB fantasy football is an auction format that utilizes a blind bid system to acquire players off the waiver wire.
- Prior to the start of the season, each team manager is supplied with a virtual bank containing $100.
- When you’re ready to acquire a player that is currently on waivers, you will “bid” on this player. In other words, you must select a digital dollar amount that you are willing to offer in order to acquire that player.
- The player who bids the most digital money once waivers clear, the player is awarded to that owner.
- The winning bid is removed from that manager's budget.
- Ties are broken by Continual Rolling List waiver priority.
- Once you use all of your currency, you can only make bids of zero dollars.
- You can make a bid of $0 and still win a player. 
- Once waivers have cleared for the week, you will then be able to pick up any players that were not bid on instantly, for no fee.
### 4.2 Waiver Priority  
- The waiver priority will be set once at the beginning of the year.
- The initial waiver priority will be decided based on the reverse order of the draft.
### 4.3 Waiver Claims
- Waiver claims are processed in waiver priority order and each successful claim moves the manager to the end of the waiver priority list.
- Waiver claims will use a two day waiver period.
- When a player is dropped from a team, the player will be placed on waivers for two days before he can be claimed.
- After the two day period, the player becomes a free agent.

### 4.4 Post Draft Waiver Wire
- All undrafted players will be placed on waivers and become free agents after two days.

### 4.5 Waiver Period and Processing
- All unclaimed players will be placed on waivers at the start of their respective games.
- The claim period ends at 2:59AM EST on Wednesday.
- Waiver claims are processed within 4-8 hours of the claim deadline.

## 5. Monetary  
### 5.1 Fees and Collection  
- The league entry fee is $200.
- Can be paid in cash, check, or Zelle.
- Money will be collected and held by the Treasurer.

### 5.2 Distribution  
- The sum total is $2400
- The payout will be :
  - $1480 for first place
  - $420 for second place
  - $210 for third place. 
- The weekly highest scoring team will be awarded $20 weekly until week 14.
- The yearly league plaque will cost $10.
- All costs summed: $1480 + $420 + $210 + $260 + $10 = $2400
- All money will be distributed at the Summit or within 48 hours of the Summit at the latest.

## 6. Schedule
### 6.1 Schedule Planning
- The schedule will be randomly shuffled every year.

## 7. Team Structure
### 7.1 Team Size
- The team size will be 15 players maximum.
- There will be 9 active players.
- There will be 6 bench players.
- If there is an active slot available that is not filled by an active player from the bench, a warning will be issued.
  - Example: Leaving IR or BYE player in an active slot.
  - On the second occasion, a penalty will be enforced as outlined in the penalty section.

### 7.2 Position Breakdown
- There will be 1 QB.
- There will be 2 WR.
- There will be 2 RB.
- There will be 1 TE.
- There will be 1 Flex.
  - A player eligible for flex is WR, RB, or TE.
- There will be 1 K.
- There will be 1 DST

### 7.3 Injured Reserve
- There is one Injured Reserve (IR) slot available that does not count towards your active roster.
- Only players listed as IR are eligible for this slot.
- Once their IR status is removed, they must be moved to an active slot.

## 8. Scoring
### 8.1 Fractional Scoring
- All positions will implement fractional scoring

### 8.2 Points Per Reception
- All positions will recieve 0.5 points per reception (0.5PPR)

### 8.3 Quarterbacks (QB)
- The QB will earn 1 point per 20 yards of passing. 
- The QB will earn 4 points per passing touchdown.
- The QB will lose 2 points per interception.
- If the QB runs, he will score points as outlined for the RB.
- If the QB receives a pass, he will score points as outlined for the WR.

### 8.4 Running Backs (RB)
- The RB will earn 1 point per 10 yards of rushing. 
- The RB will earn 6 points per rushing touchdown.
- If the RB passes, he will score points as outlined for the QB.
- If the RB receives a pass, he will score points as outlined for the WR.

### 8.5 Wide Receivers (WR)
- The WR will earn 1 point per 10 yards after a reception. 
- The WR will earn 6 points per touchdown.
- If the WR passes, he will score points as outlined for the QB.
- If the WR runs, he will score points as outlined for the RB.

### 8.6 Tight Ends (TE)
- The TE will earn 1 point per 10 yards after a reception. 
- The TE will earn 6 points per touchdown.
- If the TE passes, he will score points as outlined for the QB.
- If the TE runs, he will score points as outlined for the RB.

### 8.7 Kickers (K)
- The K will score 1 point per 10 yards of distance.
- The K will score 1 point per PA made.
- The K will lose 1 point per PA missed.

### 8.8 All Offense
- Any player that scores on a 2-point conversion will be awarded 2 points.
- Any player that fumbles the ball will lose one point.
- Any player that fumbles the ball and the opposing team recovers will lose an additional 1 point.
- A 1 point bonus is added to any player that has 100 receiving yards.
- A 1 point bonus is added to any player that has 100 rushing yards.

### 8.9 Defense and Special Teams (DST)
- The DST will score 1 point per sack.
- The DST will score 2 points per interception.
- The DST will score 2 points per fumble recovery.
- The DST will score 6 points when the football is obtained and returned for a TD.
- The DST will score 2 points per safety.
- The DST will score 2 points per blocked kick.
- The DST will score 1 point per 25 yards with both punt and kickoff returns.
- The DST will score 6 points for kickoff and punt return touchdowns.
- The DST will start with 10 points.
- If the DST allows 0 points, they will not lose any points.
- If the DST allows 1-6 points, the DST will lose 3 points.
- If the DST allows 7-13 points, the DST will lose an additional 3 points.
- If the DST allows 14-20 points, the DST will lose an additional 3 points.
- If the DST allows 21-27 points, the DST will lose an additional 1 point.
- If the DST allows 28-34 points, the DST will lose an additional 1 point.
- If the DST allows 35+ points, the DST will lose an additional 3 points.
- The DST will score 1 point per 4th down stop.
- The DST will score 2 points for the extra point returned.

## 9. Penalities
### 9.1 Illegal Lineups
- Prior to setting an illegal lineup, the manager will be warned once.
- If they set an illegal lineup for a second week, their team will be docked $20 FAAB.


## 10. Communication
### 10.1 League Wide Announcements
- All league wide announcements will be made via Signal.
### 10.2 Signal 
- The CA will be in charge of moderating the Signal chat.
- The CA has autonomy of the Signal chat and can override any decisions made by the Commissioner.

## 11. Playoffs
### 11.1 Playoff Qualifying
- The top six teams will advance to the playoffs.
- In the event of a tie, the tie-breaker will be overall point total.
- The teams that do not make it to the playoffs will not be able to pick up free agents or make waiver claims.

### 11.2 Playoff Seeding
- The top two seeds will have a first round bye.
- The teams in the playoffs will be reseeded.
- The #1 seed will play the winner of the #4 seed and #5 seed matchup.
- The #2 seed will play the winner of the #3 seed and #6 seed matchup.
- The two losing teams from the second round of the playoffs will play each other for third place.

### 11.3 Playoff Schedule
- Playoffs will occur during week 15 through week 17.
- Once the playoffs start, the standings will no longer update.

### 11.4 Playoff Waivers
- The priority list will no longer reset and waiver priority will be based on a continual rolling list with a baseline of the final regular-season standings.

### 11.5 Eliminated teams
- Any team eliminated in the first round will have their team locked. The teams will not be able to pick up free agents or make waiver claims.

## 12. Awards
### 12.1 Trophy
- The trophy for first place will be rewarded at the annual Summit.
### 12.2 Prize Money
- The prize money, for both playoffs and best weekly record, will be paid out within 48 hours of the Summit by the Treasurer.

## 13. Rule Ammendments
### 2015 Summit Topics
- League name, open to suggestions
- League size, 10 or 12
- Adding or removing people based on participation
- League fee increase to $100
  - What is the payout
- Should there be divisions?
- Need new rules to implement for trade processes
- How should we determine the draft order?
- Should we change scoring for QB TDs?
- Do we want to make this a dynasty league?

### 2015 Summit Outcomes
- The league will be renamed, all suggestions welcome.
- The league will remain a 10 team league.
- League fee increased to $100 with 60-20-10 payout and weekly high score winners getting the remaining 10%.
- Jason Rule: Trades must take one day to process and go through commissioner approval. [Robbery of George]
- Jake Rule: Must have any player traded for on your 15-man roster for one week. [Etrz-Tannehill Fiasco]
- Ziad Rule: Don't trust Ziad's advice. [Weekly Lies] 
- Bashar Rule: Waiver priority will not reset every week. The priority will be set once; reverse order of the draft. [First WW priority for entire season]
- Mike Rule: Scoring will be modified for 4 pt QB TDs. [Tom Fucking Brady]
- In person draft will be mandatory. Only excuses are work or family issue. 
- Summit discussion will also be high advised. If unable to attend, no complaints about the rules and adjustments decided upon.
- Waiver priority will not reset every week. If a waiver is submitted, the priority moves to the bottom of the list. If not, the waiver priority moves to the next week.
- The priority will be set once; the reverse order of the draft.
- If you trade for a player, they must remain on your 15-man roster for one week. They do not need to be active however.
- If there are any violations to the previous trade rule or any other rule, your team will be immediately locked for one week. Locked means zero activity allowed.
- Trades will be discussed with the two active parties and the commissioner. The commissioner will use his discretion along with the CBS trade value chart to evaluate the fairness of the trade. Once approved the trade will be allowed. If the commissioner wishes to trade, Mike or Ziad will be the third approver of the trade using the same process.
- Bench size will remain the same
- There will be no divisions
- We will let Yahoo decide playoff tie-breakers and seedings.
- QB TDs will move from 6 points to 4 points.
- Kickers who miss PAs will lose 1 point.
- Fumbles will now cost a player 1 point.
- Fumbles lost to the other team will cost an additional 1 point.
- DSTs will now score 1 point per 25 yards of kick-off or punt return yards.
- Saturday will be the last day for point corrections and will be corrected by the commissioner manually. This was previously done on Thursday.
- In the playoffs however, stat changes will only be effective until Thursday. Only extreme conditions will warrant manual change but this is highly unadvisable.
- The last place person will have a 30 minute roast of them at the summit.

### 2016 Summit Topics
- Do we move to FAAB?
- How are WW handed in the playoffs?
- When should trading not be allowed?
- Do we change the schedule?
- Slash Bashar's tires?
- Do we move to PPR?
- Should we have a live draft?
- Do we move to Fantrax?
- Allow for fractional kicking scoring?
- How to handle points scored by the defense?
- What is an illegal roster?
- How to handle early waiver wire activity?
- Electoral voting for trades?
- Should we reseed the playoffs?
- Do we modify defensive scoring?
- Do we want to keep kickers?
- Should we have a losers bracket?

### 2016 Summit Outcomes
- The waiver system will move over to FAAB with $100 budget
- Weekly highest scoring will start in week 4 and go through week 13.
- No issues with trading periods.
- No penalty for missed FGs.
- The schedule will be randomly shuffled every year.
- There will be no rivalry week.
- The scoring system will change to a 0.5 PPR league.
- The draft will be done live on a draft board.
- No Fantrax, Ziad stop asking
- Illegal roster - Must have 9 people active by Monday; no empty slots for Monday night game.
- Players will be put on waivers at the start of their respective game time.
- The playoffs will be reseeded.
- 4th down stops earn a DST 1 point.
- Kickers are still a position in the league
- In the Loser’s Bracket, the teams will be locked.

### 2017 Summit Topics
- Should we have a co-comissioner?
- Should we update the league fee from $100?
- Up the league size to 12?
- Add an additional bench spot?
- Remove kickers as a position?
- Kick Jason from the league?
- The "play 2 games" scoring system?
- Use next years draft spots in trades?
- Keeper/Dynasty league?
- Consolation bracket or structure?
- $10 weekly pay out or more?
- How to handle the 2018 draft?
- How to handle open bets?

### 2017 Summit Outcomes
- No co-comissioner
- League fee is upped to $150
- Keep league at 10
- No additional bench spot
- Keep kickers
- Keep Jason
- No new scoring system
- No trading draft picks
- No keeper or dynasty
- No consolation bracket
- Move weekly payout to $20
- In person BBQ for draft
- Establish a vig system

### 2018 Summit Topics

### 2018 Summit Outcomes

### 2019 Summit Topics
- Change kicker scoring to three points for all kicks?
- Remove the kicker position?
- Earlier waiver period for TNF players?
- How to handle rage quitting
- Two IR spots?
- Do we do a toilet bowl?
- Add superflex?
- How to handle sixth playoff spot?
- Move to full PPR?
- Move to 12 man league?
- Add point per rushing attempt?

### 2019 Summit Outcomes
- Keep kicker scoring as is.
- Keep the kicker position.
- 5 day timeout for rage quitting
- Keep only one IR spot
- No toilet bowl
- No super flex
- Sixth playoff spot is strictly determined byt PF and ignores record.
- Keep 0.5PPR
- No 12 man league
- Do not add point per rush

### 2020 Summit Topics
- Do we switch to sleepr? BA
- Raise league fee? - RB
- 12 man league? - TB
- Daily waivers - BK
- Add WR and flex - MG
- Move QB scoring to 1pt/20yds - RB

### 2020 Summit Outcomes
- Stay with Yahoo
- League fee stays $150
- QB scoring is now 1pt/20yds
- No daily waivers
- Penalties are now: 1. Warning, 2. $20 FAAB penality, 3. $20 to overall pool

### 2021 Summit Topics
- Do we add bonuses for rushing and receiving?
- Do we change to superflex?
- Do we change to 2QB?
- Raise buy in to $200
- Wildcard spot if possible

### 2021 Summit Outcomes
- Adding 1 bonus point for 100 rushing yards
- Adding 1 bonus point for 100 receiving yards
- No superflex
- No 2QB
- Raising league fee to $200, hold for the next 2 years